@@ -125,7 +125,7 @@ class MDocument(metaclass=MetaDocument):
         """Creates new document."""
 
         query = args[0]
-        cls.Model.validate(query)
+        cls.Model.validate(query, pre_insert=True)
         cls.Model.pop_optional_none(query)
         await cls.collection.insert_one(*args, **kwargs)
         return cls(query)
