@@ -49,6 +49,12 @@ class Field:
 
         return isinstance(self.type, Field) or issubclass(self.type, MDocument)
 
+    @property
+    def is_primary(self):
+        if self.model is not None:
+            return self.model.__primary_key__ == self.name
+        return False
+
     def to_dict(self):
         return {
             "type": self.type,
